API Reference
=============

.. module:: fixit

Simple API
----------

.. autofunction:: fixit_paths
.. autofunction:: fixit_file

.. autoclass:: Result


Advanced API
------------

.. autofunction:: fixit_bytes

.. autoclass:: Config
